density_plot_row_sd: Plot variablity of methylation signals across loci.

View source: R/most-variable.R

density_plot_row_sdR Documentation

Plot variablity of methylation signals across loci.

Description

Plot the distribution of standard deviation of methylation across loci. If top_n is specified, add vertical line to denote where the minimum of SD of the top variably methylated locus is.

Usage

density_plot_row_sd(x, top_n = 1000)

Arguments

x

A matrix of beta values.

top_n

An integer of top N probes. Default to 1000.

Value

A ggplot object.


markgene/yamatClassifier documentation built on Oct. 14, 2024, 2:36 a.m.