View source: R/most-variable.R
| density_plot_row_sd | R Documentation |
Plot the distribution of standard deviation of methylation across loci.
If top_n is specified, add vertical line to denote where the
minimum of SD of the top variably methylated locus is.
density_plot_row_sd(x, top_n = 1000)
x |
A matrix of beta values. |
top_n |
An integer of top N probes. Default to 1000. |
A ggplot object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.